@@ -1,4 +1,4 @@
-# TODO: streamline saving all plots a la ggsave: filename, path, different supported devices instead of only png(); automatic addition of pitch jumps at high temp in soundgen() (?)
+# TODO: morph() - tempEffects; streamline saving all plots a la ggsave: filename, path, different supported devices instead of only png(); automatic addition of pitch jumps at high temp in soundgen() (?)
 
 #' @import stats graphics utils grDevices
 #' @encoding UTF-8
@@ -176,7 +176,9 @@ NULL
 #'   range in \code{permittedValues}: 'adjust' = reset to default value, 'abort'
 #'   = stop execution, 'ignore' = throw a warning and continue (may crash)
 #' @param plot if TRUE, plots a spectrogram
-#' @param play if TRUE, plays the synthesized sound. In case of errors, try
+#' @param play if TRUE, plays the synthesized sound using the default player on
+#'   your system. If character, passed to \code{\link[tuneR]{play}} as the name
+#'   of player to use, eg "aplay", "play", "vlc", etc. In case of errors, try
 #'   setting another default player for \code{\link[tuneR]{play}}
 #' @param savePath full path for saving the output, e.g. '~/Downloads/temp.wav'.
 #'   If NA (default), doesn't save anything
@@ -187,7 +189,9 @@ NULL
 #' # NB: GUI for soundgen is available as a Shiny app.
 #' # Type "soundgen_app()" to open it in default browser
 #'
-#' playback = c(TRUE, FALSE)[2]  # set to TRUE to play back the audio from examples
+#'# Set "playback" to TRUE for default system player or the name of preferred
+#' # player (eg "aplay") to play back the audio from examples
+#' playback = c(TRUE, FALSE, 'aplay', 'vlc')[2]
 #'
 #' sound = soundgen(play = playback)
 #' # spectrogram(sound, 16000, osc = TRUE)
@@ -725,7 +729,7 @@ soundgen = function(
           l = permittedValues[pars_to_vary[p], 'low']
           h = permittedValues[pars_to_vary[p], 'high']
           sd = (h - l) * temperature * tempEffects$specDep
-          pars_syllable[[pars_to_vary[p]]] = rnorm_bounded(
+          pars_syllable[[pars_to_vary[p]]] = rnorm_truncated(
             n = length(par_value),
             mean = par_value,
             low = l,
@@ -883,7 +887,7 @@ soundgen = function(
               invalidArgAction = invalidArgAction
             )
           } else {
-            rolloffNoise_syl = rnorm_bounded(
+            rolloffNoise_syl = rnorm_truncated(
               n = length(rolloffNoise),
               mean = rolloffNoise,
               sd = abs(rolloffNoise) * temperature * tempEffects$specDep,
@@ -1109,9 +1113,11 @@ soundgen = function(
     bout = c(rep(0, n), bout, rep(0, n))
   }
 
-  if (play) {
+  if (play == TRUE) {
     playme(bout, samplingRate = samplingRate)
-    # spectrogram((soundFiltered, samplingRate = samplingRate, osc = TRUE)
+  }
+  if (is.character(play)) {
+    playme(bout, samplingRate = samplingRate, player = play)
   }
   if (!is.na(savePath)) {
     seewave::savewav(bout, filename = savePath, f = samplingRate)
